# model export using [ONNX](https://github.com/onnx/onnx) for deployment
TODO....

## ONNX

to write

## Model Quantization

to write

## More topics...


## References:
1. [ONNX Tutorials](https://github.com/onnx/tutorials)
2. [PyTorch Tutorials](https://pytorch.org/tutorials/advanced/super_resolution_with_onnxruntime.html)
3. [PyTorch Docs](https://pytorch.org/docs/stable/onnx.html)
4. to add more....
